.. Copyright 2011, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Reahl
=====

The Reahl web application framework allows a programmer to write web
applications in pure Python. No HTML/CSS/JavaScript needed. No need to
learn all sorts of web design tricks. Just Python.

Alongside its web application framework, Reahl also includes
"components": bits of pre-built functionality like the plugins of a
content management system. There's no need to write everything from
scratch unless you really need to.

Much of what is included in Reahl is also useful outside of a web
programming context.

Learn more:
 - A superficial example for the very impatient (example.rst)
 - An explanation of basic web framework programming (webframeworkintro.rst)
 - The underlying component framework 
 - Some advocacy: reasons why you may want to use Reahl (advocacy.rst)


